![](https://mrlucascardoso.github.io/awesome-mixins-docs/images/logo.png)


Set of the mixins for class based view on django.

Coming soon... [DOCS](https://mrlucascardoso.github.io/awesome-mixins-docs/) <- Take a look :sweat_smile:

At the moment us only have ListMixin available :disappointed_relieved:, but I'm arranging to improve and add new functions to the project.
 
![](https://media.tenor.co/images/64d26d582e2e5aedf9ce035c63e1f1d9/tenor.gif)

Feel free to contribute :thumbsup: